==> shrinkwrap-resolver-parent-3.1.6-source-release.zip: shrinkwrap-resolver-parent-3.1.6/maven/impl-maven/src/test/java/org/jboss/shrinkwrap/resolver/impl/maven/MavenRepositorySystemTestCase.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.shrinkwrap.resolver.impl.maven;


import org.jboss.shrinkwrap.resolver.api.Resolvers;
import org.jboss.shrinkwrap.resolver.api.maven.MavenResolverSystem;
import org.junit.Assert;
import org.junit.Test;

/**
 *
 * @author <a href="mailto:kpiwko@redhat.com">Karel Piwko</a>
 *
 */
public class MavenRepositorySystemTestCase {

    @Test
    public void bootstrap() {
        Assert.assertNotNull("Maven Resolver System can be bootstrapped", Resolvers.use(MavenResolverSystem.class));
    }

    @Test
    public void bootstrapWithClassloader() {
        Assert.assertNotNull("Maven Resolver System can be bootstrapped with classloader",
            Resolvers.use(MavenResolverSystem.class, Thread.currentThread().getContextClassLoader()));
    }

}

==> shrinkwrap-resolver-parent-3.3.2-source-release.zip: shrinkwrap-resolver-parent-3.3.2/maven/impl-maven/src/test/java/org/jboss/shrinkwrap/resolver/impl/maven/MavenRepositorySystemTestCase.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.shrinkwrap.resolver.impl.maven;


import org.jboss.shrinkwrap.resolver.api.Resolvers;
import org.jboss.shrinkwrap.resolver.api.maven.MavenResolverSystem;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 *
 * @author <a href="mailto:kpiwko@redhat.com">Karel Piwko</a>
 *
 */
class MavenRepositorySystemTestCase {

    @Test
    void bootstrap() {
        Assertions.assertNotNull(Resolvers.use(MavenResolverSystem.class), "Maven Resolver System can be bootstrapped");
    }

    @Test
    void bootstrapWithClassloader() {
        Assertions.assertNotNull(Resolvers.use(MavenResolverSystem.class, Thread.currentThread().getContextClassLoader()), "Maven Resolver System can be bootstrapped with classloader");
    }

}
